# Scrapfly SDK

## Installation

`pip install scrapfly-sdk`

You can also install extra dependencies to improve performance (recommended)

`pip install "scrapfly-sdk[seepdup]"`

* [Usage](https://scrapfly.io/docs/sdk/python)
* [Python API](https://scrapfly.github.io/python-scrapfly/scrapfly)
* [Open API 3 Spec](https://scrapfly.io/docs/openapi#get-/scrape) 
